@@ -1,5 +1,10 @@
+from __future__ import unicode_literals
+
 import csv
+
 from django.http import HttpResponse
+from django.utils import six
+
 
 # Admin action for a generic "CSV Export"
 # Django snippets: http://djangosnippets.org/snippets/2369/
@@ -25,14 +30,14 @@ def export_as_csv_action(description="Export selected objects as CSV file",
             excludeset = set(exclude)
             field_names = field_names - excludeset
 
-        response = HttpResponse(mimetype='text/csv')
-        response['Content-Disposition'] = 'attachment; filename=%s.csv' % unicode(opts).replace('.', '_')
+        response = HttpResponse(content_type='text/csv')
+        response['Content-Disposition'] = 'attachment; filename=%s.csv' % six.text_type(opts).replace('.', '_')
 
         writer = csv.writer(response)
         if header:
             writer.writerow(list(field_names))
         for obj in queryset:
-            writer.writerow([unicode(getattr(obj, field)).encode("utf-8","replace") for field in field_names])
+            writer.writerow([six.text_type(getattr(obj, field)).encode('utf-8', 'replace') for field in field_names])
         return response
     export_as_csv.short_description = description
     return export_as_csv
